
unit main;

{$IFDEF FPC}{$MODE objfpc}{$H+}{$ENDIF}

interface

uses
  sysutils,
  mseglob, mseguiglob, mseguiintf, mseapplication, msestat, msegui, msegraphics,
  msegraphutils, mseclasses, mseforms, msesimplewidgets, msemenus, msewidgets,
  msetimer;

type
  tmainfo = class(tmainform)
    animationpaintbox: tpaintbox;
    mseguiversion: tlabel;
    bgrabitmapversion: tlabel;
    animationtimer: ttimer;
    startstopbutton: tbutton;
    procedure paintbox_onpaint(const sender: twidget; const acanvas: tcanvas);
    procedure mainform_oncreate(const sender: TObject);
    procedure timer_ontimer(const sender: TObject);
    procedure button_onexec(const sender: TObject);
  end;
  
var
  mainfo: tmainfo;
  
implementation

uses
  main_mfm, bgrabitmap, bgrabitmaptypes, bgragraphics;

const
  cpixels: array[0..6] of tbgrapixel = (
    (blue: 255; green: 0; red: 0; alpha: 255),
    (blue: 255; green: 0; red: 0; alpha: 223),
    (blue: 255; green: 0; red: 0; alpha: 191),
    (blue: 255; green: 0; red: 0; alpha: 159),
    (blue: 255; green: 0; red: 0; alpha: 127),
    (blue: 255; green: 0; red: 0; alpha:  95),
    (blue: 255; green: 0; red: 0; alpha:  63)
  );

var
  langle: single;
  lbreakafter: integer;
    
procedure tmainfo.paintbox_onpaint(const sender: twidget; const acanvas: tcanvas);
const
  cdelta = pi / 8;
var
  lbitmap: tbgrabitmap;
  lindex: integer;
  lradius: integer;
begin    
  lbitmap := tbgrabitmap.create(sender.bounds_cx, sender.bounds_cy);
  lradius := sender.bounds_cx div 6;
  
  for lindex := low(cpixels) to high(cpixels) do
  begin
    lbitmap.fillellipseantialias(
      sender.bounds_cx / 2 + (sender.bounds_cx div 3) * cos(langle - lindex * cdelta),
      sender.bounds_cy / 2 - (sender.bounds_cy div 3) * sin(langle - lindex * cdelta),
      10,
      10,
      cpixels[lindex]
    );
    if lindex = lbreakafter then
      break;
  end;
  lbitmap.draw(acanvas, 0, 0, false);
  lbitmap.free;
end;

procedure tmainfo.mainform_oncreate(const sender: TObject);
begin
  mseguiversion.caption := format('MSEgui %s', [mseguiversiontext]);
  bgrabitmapversion.caption := format('BGRABitmap %s', [bgrabitmapversionstr]);
  langle := 0;
  lbreakafter := 0;
end;

procedure tmainfo.timer_ontimer(const sender: TObject);
const
  cdelta = pi / 8;
begin
  langle := langle + cdelta;
  if lbreakafter <= high(cpixels) then
    inc(lbreakafter);
  invalidate;
end;

procedure tmainfo.button_onexec(const sender: TObject);
const
  ccaption: array[boolean] of string = ('Start', 'Stop');
begin
  animationtimer.enabled := not animationtimer.enabled;
  startstopbutton.caption := ccaption[animationtimer.enabled];
end;

end.
